@@ -14,7 +14,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, List, Type, Union, overload
 
 from botocore.client import ClientMeta
 
@@ -120,7 +120,7 @@ class Exceptions:
 
 class WorkDocsClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html)
     """
 
@@ -131,7 +131,10 @@ class WorkDocsClient:
         self, *, DocumentId: str, VersionId: str, AuthenticationToken: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.abort_document_version_upload)
+        Aborts the upload of the specified document version that was previously
+        initiated by  InitiateDocumentVersionUpload.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.abort_document_version_upload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#abort_document_version_upload)
         """
 
@@ -139,7 +142,9 @@ class WorkDocsClient:
         self, *, UserId: str, AuthenticationToken: str = None
     ) -> ActivateUserResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.activate_user)
+        Activates the specified user.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.activate_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#activate_user)
         """
 
@@ -147,18 +152,22 @@ class WorkDocsClient:
         self,
         *,
         ResourceId: str,
-        Principals: List[SharePrincipalTypeDef],
+        Principals: List["SharePrincipalTypeDef"],
         AuthenticationToken: str = None,
-        NotificationOptions: NotificationOptionsTypeDef = None
+        NotificationOptions: "NotificationOptionsTypeDef" = None
     ) -> AddResourcePermissionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.add_resource_permissions)
+        Creates a set of permissions for the specified folder or document.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.add_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#add_resource_permissions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#can_paginate)
         """
 
@@ -175,7 +184,9 @@ class WorkDocsClient:
         NotifyCollaborators: bool = None
     ) -> CreateCommentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.create_comment)
+        Adds a new comment to the specified document version.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_comment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_comment)
         """
 
@@ -188,7 +199,10 @@ class WorkDocsClient:
         VersionId: str = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.create_custom_metadata)
+        Adds one or more custom properties to the specified resource (a folder,
+        document, or version).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_custom_metadata)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_custom_metadata)
         """
 
@@ -196,7 +210,9 @@ class WorkDocsClient:
         self, *, ParentFolderId: str, AuthenticationToken: str = None, Name: str = None
     ) -> CreateFolderResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.create_folder)
+        Creates a folder with the specified name and parent folder.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_folder)
         """
 
@@ -204,7 +220,13 @@ class WorkDocsClient:
         self, *, ResourceId: str, Labels: List[str], AuthenticationToken: str = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.create_labels)
+        Adds the specified list of labels to the given resource (a document or folder)
+        See also: `AWS API Documentation
+        <https://docs.aws.amazon.com/goto/WebAPI/workdocs-2016-05-01/CreateLabels>`_
+        **Request Syntax** response = client.create_labels( ResourceId='string',
+        Labels=[ ...
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_labels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_labels)
         """
 
@@ -217,7 +239,9 @@ class WorkDocsClient:
         SubscriptionType: Literal["ALL"]
     ) -> CreateNotificationSubscriptionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.create_notification_subscription)
+        Configure Amazon WorkDocs to use Amazon SNS notifications.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_notification_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_notification_subscription)
         """
 
@@ -235,13 +259,18 @@ class WorkDocsClient:
         AuthenticationToken: str = None
     ) -> CreateUserResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.create_user)
+        Creates a user in a Simple AD or Microsoft AD directory.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_user)
         """
 
     def deactivate_user(self, *, UserId: str, AuthenticationToken: str = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.deactivate_user)
+        Deactivates the specified user, which revokes the user's access to Amazon
+        WorkDocs.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.deactivate_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#deactivate_user)
         """
 
@@ -249,7 +278,9 @@ class WorkDocsClient:
         self, *, DocumentId: str, VersionId: str, CommentId: str, AuthenticationToken: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.delete_comment)
+        Deletes the specified comment from the document version.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_comment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_comment)
         """
 
@@ -263,25 +294,33 @@ class WorkDocsClient:
         DeleteAll: bool = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.delete_custom_metadata)
+        Deletes custom metadata from the specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_custom_metadata)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_custom_metadata)
         """
 
     def delete_document(self, *, DocumentId: str, AuthenticationToken: str = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.delete_document)
+        Permanently deletes the specified document and its associated metadata.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_document)
         """
 
     def delete_folder(self, *, FolderId: str, AuthenticationToken: str = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.delete_folder)
+        Permanently deletes the specified folder and its contents.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_folder)
         """
 
     def delete_folder_contents(self, *, FolderId: str, AuthenticationToken: str = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.delete_folder_contents)
+        Deletes the contents of the specified folder.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_folder_contents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_folder_contents)
         """
 
@@ -294,19 +333,25 @@ class WorkDocsClient:
         DeleteAll: bool = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.delete_labels)
+        Deletes the specified list of labels from a resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_labels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_labels)
         """
 
     def delete_notification_subscription(self, *, SubscriptionId: str, OrganizationId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.delete_notification_subscription)
+        Deletes the specified subscription from the specified organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_notification_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_notification_subscription)
         """
 
     def delete_user(self, *, UserId: str, AuthenticationToken: str = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.delete_user)
+        Deletes the specified user from a Simple AD or Microsoft AD directory.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_user)
         """
 
@@ -314,8 +359,8 @@ class WorkDocsClient:
         self,
         *,
         AuthenticationToken: str = None,
-        StartTime: datetime = None,
-        EndTime: datetime = None,
+        StartTime: Union[datetime, str] = None,
+        EndTime: Union[datetime, str] = None,
         OrganizationId: str = None,
         ActivityTypes: str = None,
         ResourceId: str = None,
@@ -325,7 +370,9 @@ class WorkDocsClient:
         Marker: str = None
     ) -> DescribeActivitiesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.describe_activities)
+        Describes the user activities in a specified time period.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_activities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_activities)
         """
 
@@ -339,7 +386,9 @@ class WorkDocsClient:
         Marker: str = None
     ) -> DescribeCommentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.describe_comments)
+        List all the comments for the specified document version.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_comments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_comments)
         """
 
@@ -354,7 +403,9 @@ class WorkDocsClient:
         Fields: str = None
     ) -> DescribeDocumentVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.describe_document_versions)
+        Retrieves the document versions for the specified document.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_document_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_document_versions)
         """
 
@@ -371,7 +422,10 @@ class WorkDocsClient:
         Include: str = None
     ) -> DescribeFolderContentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.describe_folder_contents)
+        Describes the contents of the specified folder, including its documents and
+        subfolders.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_folder_contents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_folder_contents)
         """
 
@@ -385,7 +439,9 @@ class WorkDocsClient:
         Limit: int = None
     ) -> DescribeGroupsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.describe_groups)
+        Describes the groups specified by the query.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_groups)
         """
 
@@ -393,7 +449,9 @@ class WorkDocsClient:
         self, *, OrganizationId: str, Marker: str = None, Limit: int = None
     ) -> DescribeNotificationSubscriptionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.describe_notification_subscriptions)
+        Lists the specified notification subscriptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_notification_subscriptions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_notification_subscriptions)
         """
 
@@ -407,7 +465,9 @@ class WorkDocsClient:
         Marker: str = None
     ) -> DescribeResourcePermissionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.describe_resource_permissions)
+        Describes the permissions of a specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_resource_permissions)
         """
 
@@ -415,7 +475,10 @@ class WorkDocsClient:
         self, *, AuthenticationToken: str, Limit: int = None, Marker: str = None
     ) -> DescribeRootFoldersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.describe_root_folders)
+        Describes the current user's special folders; the `RootFolder` and the
+        `RecycleBin`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_root_folders)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_root_folders)
         """
 
@@ -434,7 +497,9 @@ class WorkDocsClient:
         Fields: str = None
     ) -> DescribeUsersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.describe_users)
+        Describes the specified users.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_users)
         """
 
@@ -446,13 +511,18 @@ class WorkDocsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#generate_presigned_url)
         """
 
     def get_current_user(self, *, AuthenticationToken: str) -> GetCurrentUserResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.get_current_user)
+        Retrieves details of the current user for whom the authentication token was
+        generated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_current_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_current_user)
         """
 
@@ -464,7 +534,9 @@ class WorkDocsClient:
         IncludeCustomMetadata: bool = None
     ) -> GetDocumentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.get_document)
+        Retrieves details of a document.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document)
         """
 
@@ -478,7 +550,10 @@ class WorkDocsClient:
         Marker: str = None
     ) -> GetDocumentPathResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.get_document_path)
+        Retrieves the path information (the hierarchy from the root folder) for the
+        requested document.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_document_path)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document_path)
         """
 
@@ -492,7 +567,9 @@ class WorkDocsClient:
         IncludeCustomMetadata: bool = None
     ) -> GetDocumentVersionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.get_document_version)
+        Retrieves version metadata for the specified document.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_document_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document_version)
         """
 
@@ -500,7 +577,9 @@ class WorkDocsClient:
         self, *, FolderId: str, AuthenticationToken: str = None, IncludeCustomMetadata: bool = None
     ) -> GetFolderResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.get_folder)
+        Retrieves the metadata of the specified folder.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_folder)
         """
 
@@ -514,7 +593,10 @@ class WorkDocsClient:
         Marker: str = None
     ) -> GetFolderPathResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.get_folder_path)
+        Retrieves the path information (the hierarchy from the root folder) for the
+        specified folder.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_folder_path)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_folder_path)
         """
 
@@ -528,7 +610,9 @@ class WorkDocsClient:
         Marker: str = None
     ) -> GetResourcesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.get_resources)
+        Retrieves a collection of resources, including folders and documents.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_resources)
         """
 
@@ -539,13 +623,15 @@ class WorkDocsClient:
         AuthenticationToken: str = None,
         Id: str = None,
         Name: str = None,
-        ContentCreatedTimestamp: datetime = None,
-        ContentModifiedTimestamp: datetime = None,
+        ContentCreatedTimestamp: Union[datetime, str] = None,
+        ContentModifiedTimestamp: Union[datetime, str] = None,
         ContentType: str = None,
         DocumentSizeInBytes: int = None
     ) -> InitiateDocumentVersionUploadResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.initiate_document_version_upload)
+        Creates a new document object and version object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.initiate_document_version_upload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#initiate_document_version_upload)
         """
 
@@ -553,7 +639,9 @@ class WorkDocsClient:
         self, *, ResourceId: str, AuthenticationToken: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.remove_all_resource_permissions)
+        Removes all the permissions from the specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.remove_all_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#remove_all_resource_permissions)
         """
 
@@ -566,7 +654,9 @@ class WorkDocsClient:
         PrincipalType: PrincipalTypeType = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.remove_resource_permission)
+        Removes the permission for the specified principal from the specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.remove_resource_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#remove_resource_permission)
         """
 
@@ -580,7 +670,9 @@ class WorkDocsClient:
         ResourceState: ResourceStateTypeType = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.update_document)
+        Updates the specified attributes of a document.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.update_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_document)
         """
 
@@ -593,7 +685,9 @@ class WorkDocsClient:
         VersionStatus: Literal["ACTIVE"] = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.update_document_version)
+        Changes the status of the document version to ACTIVE.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.update_document_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_document_version)
         """
 
@@ -607,7 +701,9 @@ class WorkDocsClient:
         ResourceState: ResourceStateTypeType = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.update_folder)
+        Updates the specified attributes of the specified folder.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.update_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_folder)
         """
 
@@ -625,7 +721,10 @@ class WorkDocsClient:
         GrantPoweruserPrivileges: BooleanEnumTypeType = None
     ) -> UpdateUserResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Client.update_user)
+        Updates the specified attributes of the specified user, and grants or revokes
+        administrative privileges to the Amazon WorkDocs site.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_user)
         """
 
@@ -634,7 +733,8 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_activities"]
     ) -> DescribeActivitiesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeactivitiespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeactivitiespaginator)
         """
 
     @overload
@@ -642,7 +742,8 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_comments"]
     ) -> DescribeCommentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describecommentspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describecommentspaginator)
         """
 
     @overload
@@ -650,7 +751,8 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_document_versions"]
     ) -> DescribeDocumentVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describedocumentversionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describedocumentversionspaginator)
         """
 
     @overload
@@ -658,13 +760,15 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_folder_contents"]
     ) -> DescribeFolderContentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describefoldercontentspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describefoldercontentspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_groups"]) -> DescribeGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describegroupspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describegroupspaginator)
         """
 
     @overload
@@ -672,7 +776,8 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_notification_subscriptions"]
     ) -> DescribeNotificationSubscriptionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describenotificationsubscriptionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describenotificationsubscriptionspaginator)
         """
 
     @overload
@@ -680,7 +785,8 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_resource_permissions"]
     ) -> DescribeResourcePermissionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeresourcepermissionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeresourcepermissionspaginator)
         """
 
     @overload
@@ -688,11 +794,13 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_root_folders"]
     ) -> DescribeRootFoldersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describerootfolderspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describerootfolderspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_users"]) -> DescribeUsersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeuserspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeuserspaginator)
         """
